=====================
bw2scaffold Changelog
=====================

Version 0.0.9
=============

+ version bump to synchronize pipelines

Version 0.0.7
=============

+ fixed issue with directories

Version 0.0.6
=============

+ working prototype
